import request from "@/utils/request";

//
export function getInfoList(data) {
  return request({
    url: "/admin/video/live/info/list",
    method: "post",
    data
  });
}
// 后台查询专栏列表
export function getColumnList(data) {
  return request({
    url: "/admin/video/live/column/list",
    method: "post",
    data
  });
}

// 后台创建视频直播
export function save(data) {
  return request({
    url: "/admin/video/live/info/save",
    method: "post",
    data
  });
}

export function batchSave(data) {
  return request({
    url: "/admin/video/live/info/batchSave",
    method: "post",
    data
  });
}

// 后台更新视频信息
export function update(data) {
  return request({
    url: "/admin/video/live/info/update",
    method: "post",
    data
  });
}

// 后台标签列表
export function tagList(data) {
  return request({
    url: "/admin/common/tag/list",
    method: "post",
    data
  });
}
// 后台标签列表
export function uploadSign(data) {
  return request({
    url: "/admin/video/live/uploadSign",
    method: "get",
    data
  });
}

// 后台标签列表
export function librarySave(data) {
  return request({
    url: "/admin/video/live/library/save",
    method: "post",
    data
  });
}
// 后台标签列表
export function livePlayInfo(params) {
  return request({
    url: "/admin/video/live/playInfo",
    method: "get",
    params
  });
}

// 后台标签列表
export function infoSubmit(data) {
  return request({
    url: "/admin/video/live/info/submit",
    method: "post",
    data
  });
}
// 行为数据统计
export function cartList(params) {
  return request({
    url: "/app/video/live/cartList",
    method: "get",
    params
  });
}

export function infoGet(params) {
  return request({
    url: "/admin/video/live/info/get",
    method: "get",
    params
  });
}
// 后台撤回操作
export function infoRecall(data) {
  return request({
    url: "/admin/video/live/info/recall",
    method: "post",
    data
  });
}

export function behaviorStatistic(params) {
  return request({
    url: "/admin/video/live/behavior-statistic",
    method: "get",
    params
  });
}
// 客户数据统计
export function behaviorUser(data) {
  return request({
    url: "/admin/video/live/behavior-user-of-one",
    method: "post",
    data
  });
}

// 行为数据统计详情(某直播客户统计)
export function behaviorStaff(data) {
  return request({
    url: "/admin/video/live/behavior-staff-of-one",
    method: "post",
    data
  });
}
// 后台审核视频直播
export function updateStatus(data) {
  return request({
    url: "/admin/video/live/info/updateStatus",
    method: "post",
    data
  });
}

// 后台保存推荐位
export function recommendSave(data) {
  return request({
    url: "/admin/video/live/info/recommend",
    method: "post",
    data
  });
}

// 后台保存推荐位
export function rLiveWsConfig(params) {
  return request({
    url: "/admin/common/getWebSocketConf",
    method: "get",
    params
  });
}

export function uVideoControl(data) {
  return request({
    url: "/admin/video/live/info/control",
    method: "post",
    data
  });
}

export function getPlayerSign(data) {
  return request({
    url: "/admin/video/playerSign",
    method: "post",
    data
  });
}
export function videoMessage(data) {
  return request({
    url: "/admin/video/live/message/list",
    method: "post",
    data
  });
}
// 后台删除互动消息
export function messageDelete(data) {
  return request({
    url: "/admin/video/live/message/delete",
    method: "post",
    data
  });
}
// 后台发送互动消息
export function messageSend(data) {
  return request({
    url: "/admin/video/live/message/send",
    method: "post",
    data
  });
}
// 添加用户禁言
export function addCommentBlack(data) {
  return request({
    url: "/admin/comment/addCommentBlack",
    method: "post",
    data
  });
}
// 解除用户禁言
export function removeCommentBlack(data) {
  return request({
    url: "/admin/comment/removeCommentBlack",
    method: "post",
    data
  });
}

// 中台查询禁言列表
export function queryCommentBlackList(data) {
  return request({
    url: "/admin/comment/queryCommentBlackList",
    method: "post",
    data
  });
}

// 购物车上下架
export function cartUpdateStatus(data) {
  return request({
    url: "/admin/video/live/cart/updateStatus",
    method: "post",
    data
  });
}
// 购物车修改可销售数量
export function updateSaleLimit(data) {
  return request({
    url: "/admin/video/live/cart/updateSaleLimit",
    method: "post",
    data
  });
}

// 后台停止互动
export function messageForbidden(data) {
  return request({
    url: "/admin/video/live/message/forbidden",
    method: "post",
    data
  });
}
// 后台查询观点包列表
export function packageList(data) {
  return request({
    url: "/admin/view/package/list",
    method: "post",
    data
  });
}
// 购物车推荐
export function cartRecommend(data) {
  return request({
    url: "/admin/video/live/cart/recommend",
    method: "post",
    data
  });
}
// 后台推荐产品消息
export function productMessage(data) {
  return request({
    url: "/admin/video/live/message/productMessage",
    method: "post",
    data
  });
}
// 后台查询专栏详情
export function columnGet(params) {
  return request({
    url: "/admin/video/live/column/get",
    method: "get",
    params
  });
}
// 后台查询专栏列表
export function columnList(data) {
  return request({
    url: "/admin/video/live/column/list",
    method: "post",
    data
  });
}
// 后台创建视频专栏
export function columnSave(data) {
  return request({
    url: "/admin/video/live/column/save",
    method: "post",
    data
  });
}
// 后台推荐视频专栏
export function columnRecommend(data) {
  return request({
    url: "/admin/video/live/column/recommend",
    method: "post",
    data
  });
}
// 专栏状态修改
export function columnUpdateStatus(data) {
  return request({
    url: "/admin/video/live/column/updateStatus",
    method: "post",
    data
  });
}

// 风控列表
export function riskList(data) {
  return request({
    url: "/admin/video/live/risk-list",
    method: "post",
    data
  });
}
// 直播活动列表
export function activityList(data) {
  return request({
    url: "/admin/video/live/activity/list",
    method: "post",
    data
  });
}
// 新增活动
export function activitySave(data) {
  return request({
    url: "/admin/video/live/activity/save",
    method: "post",
    data
  });
}
// 活动状态修改
export function activityUpdateStatus(data) {
  return request({
    url: "/admin/video/live/activity/updateStatus",
    method: "post",
    data
  });
}
// 后台部门(营业部、分公司)列表查询
export function deptColumnList(params) {
  return request({
    url: "/admin/rbac/dept/common/list",
    method: "get",
    params
  });
}
// 视频直播数据概况（已对接订单）
export function dataOverview(params) {
  return request({
    url: "/admin/video/live/data-overview",
    method: "get",
    params
  });
}

// 视频直播实时趋势
export function nowTrend(params) {
  return request({
    url: "/admin/video/live/nowTrend",
    method: "get",
    params
  });
}
// 客户管理列表
export function customerList(data) {
  return request({
    url: "/admin/video/live/customer/list",
    method: "post",
    data
  });
}
// 客户详情
export function customerDetails(params) {
  return request({
    url: "/admin/video/live/customer/details",
    method: "get",
    params
  });
}
// 直播观看记录
export function videoReadRecord(data) {
  return request({
    url: "/admin/video/live/customer/video-read-record",
    method: "post",
    data
  });
}
// 公开、关闭消息
export function messageOpen(data) {
  return request({
    url: "/admin/chat/message/open",
    method: "post",
    data
  });
}
// 关键行为提醒列表
export function notifyList(data) {
  return request({
    url: "/admin/video/live/behavior/notify/list",
    method: "post",
    data
  });
}
// 创建问卷
export function questionSave(data) {
  return request({
    url: "/admin/video/live/question/save",
    method: "post",
    data
  });
}
// 问卷列表
export function questionList(data) {
  return request({
    url: "/admin/video/live/question/list",
    method: "post",
    data
  });
}
// 问卷状态修改
export function questionUpdateStatus(data) {
  return request({
    url: "/admin/video/live/question/updateStatus",
    method: "post",
    data
  });
}
// 问卷详情
export function questionDetails(params) {
  return request({
    url: "/admin/video/live/question/details",
    method: "get",
    params
  });
}

// 问卷导出
export function questionExport(params) {
  return request({
    url: "/admin/video/live/question/export",
    method: "get",
    params
  });
}
// 视频直播开启消息审核
export function openMessAudit(data) {
  return request({
    url: "/admin/video/live/openMessAudit",
    method: "post",
    data
  });
}

// 生成短链
export function urlResize(data) {
  return request({
    url: "/admin/url/resize",
    method: "post",
    data
  });
}
// 查询历史消息数
export function messageCountApi(params) {
  return request({
    url: "/admin/chat/message/count",
    method: "get",
    params
  });
}
// 查询腾讯云在线人数
export function txonline(params) {
  return request({
    url: "/admin/video/live/txonline",
    method: "get",
    params
  });
}
// 点击转码直播视频
export function liveProcess(params) {
  return request({
    url: "/admin/video/live/process",
    method: "get",
    params
  });
}
// 转码视频下载地址
export function videoDownload(params) {
  return request({
    url: "/admin/video/download",
    method: "get",
    params
  });
}

// 查询视频转码进度
export function videoDownProgress(params) {
  return request({
    url: "/admin/video/live/download/progress",
    method: "get",
    params
  });
}
// 获取投顾互动消息
export function advisorMessageList(data) {
  return request({
    url: "/admin/video/live/advisorMessage/list",
    method: "post",
    data
  });
}

// 后台查询课程列表
export function courseInfoList(data) {
  return request({
    url: "/admin/course/info/list",
    method: "post",
    data
  });
}
// 后台查询合集列表
export function serialInfoList(data) {
  return request({
    url: "/admin/serial/info/list",
    method: "post",
    data
  });
}

// 修改互动类型
export function updateInteractType(data) {
  return request({
    url: "/admin/video/live/updateInteractType",
    method: "post",
    data
  });
}
// 设置首页参数
export function setMainPageParam(data) {
  return request({
    url: "/admin/video/live/setMainPageParam",
    method: "post",
    data
  });
}

// 修改二维码开关
export function updateQWParam(data) {
  return request({
    url: "/admin/video/live/updateQWParam",
    method: "post",
    data
  });
}

// 购物车产品推送
export function cartPush(data) {
  return request({
    url: "/admin/video/live/cart/push",
    method: "post",
    data
  });
}

// 终端类型统计
export function queryUserClientType(params) {
  return request({
    url: "/admin/video/live/clientType",
    method: "get",
    params
  });
}

// 查询上次转推信息
export function getLastPush(params) {
  return request({
    url: "/admin/video/live/getLastPush",
    method: "get",
    params
  });
}

// 删除转推信息
export function deletePush(data) {
  return request({
    url: "/admin/video/live/deletePush",
    method: "post",
    data
  });
}

// 保存转推信息
export function savePush(data) {
  return request({
    url: "/admin/video/live/savePush",
    method: "post",
    data
  });
}

// 保存转推信息
export function cancelPush(params) {
  return request({
    url: "/admin/video/live/cart/cancelPush",
    method: "get",
    params
  });
}

// 查询混流详情
export function getMixData(data) {
  return request({
    url: "/admin/video/mix/get",
    method: "post",
    data
  });
}

// 保存混流信息
export function saveMixData(data) {
  return request({
    url: "/admin/video/mix/save",
    method: "post",
    data
  });
}

// 修改混流主画面显示
export function updateMixShowMain(data) {
  return request({
    url: "/admin/video/mix/updateShowMain",
    method: "post",
    data
  });
}

// 修改混流连麦状态
export function updateMixStatus(data) {
  return request({
    url: "/admin/video/mix/updateStatus",
    method: "post",
    data
  });
}

// 修改是否显示完整昵称
export function showNickname(data) {
  return request({
    url: "/admin/video/live/showNickname",
    method: "post",
    data
  });
}
